# common-utils-py
Provides common functions to interact with the ocean system.

## Main components
* DID and DDO
  * DID format: 'did:op:<32bytes-hex-representation>
  * DID is the universal identifier for assets in the Ocean network
  * DDO is the json document that 
* DID resolver
  * Given a valid did, returns the associated DDO document which define 
    the asset metadata and other services offered for the asset
* Aquarius
* Service Agreements
